@@ -280,162 +280,6 @@ DLL_EXPORT int generate_lut(char *inputname,char *outputname,char *user_info,int
 DLL_EXPORT int get_lut_info(char **info,char *lut_name);
 DLL_EXPORT int get_lut_info_t(char **info,char *lut_name,KTO_CHK_CTX *ctx);
 
-
-/* die folgenden Funktionen sind Prototypen fr das LUT2-Format; die
- * zugehrigen Funktionen sind noch nicht in der aktuellen Version
- * enthalten.
- */
-
-/*
- * ######################################################################
- * # get_ident(): ident-String aus der LUT-Datei holen                  #
- * #                                                                    #
- * # Die Funktion holt den ident-String aus der LUT-Datei und gibt in   #
- * # der Variablen ident einen Pointer auf diesen String zurck. Der    #
- * # ident-String kann mittels der Funktion set_ident() gesetzt werden. #
- * #                                                                    #
- * #                                                                    #
- * # Parameter:                                                         #
- * #    ident:                                                          #
- * #    lut_name: Name der LUT-Datei                                    #
- * #                                                                    #
- * # Rckgabewerte: wie in read_lut():                                  #
- * #    ERROR_MALLOC       kann keinen Speicher allokieren              #
- * #    NO_LUT_FILE        LUT-Datei nicht gefunden (Pfad falsch?)      #
- * #    FATAL_ERROR        kann die LUT-Datei nicht lesen               #
- * #    INVALID_LUT_FILE   Fehler in der LUT-Datei (Format, CRC...)     #
- * #    NO_IDENT_BLOCK     die LUT-Datei enthlt keinen IDENT Block     #
- * #    OK                 Erfolg                                       #
- * ######################################################################
- */
-DLL_EXPORT int get_ident(char **ident,char *lut_name);
-
-/*
- * ######################################################################
- * # set_ident(): ident-String aus der LUT-Datei holen                  #
- * #                                                                    #
- * # Die Funktion setzt den ident-String in der LUT-Datei auf den       #
- * # angegebenen Wert.                                                  #
- * #                                                                    #
- * #                                                                    #
- * # Parameter:                                                         #
- * #    ident:                                                          #
- * #    lut_name: Name der LUT-Datei                                    #
- * #                                                                    #
- * # Rckgabewerte: wie in read_lut():                                  #
- * #    ERROR_MALLOC       kann keinen Speicher allokieren              #
- * #    NO_LUT_FILE        LUT-Datei nicht gefunden (Pfad falsch?)      #
- * #    FATAL_ERROR        kann die LUT-Datei nicht lesen               #
- * #    INVALID_LUT_FILE   Fehler in der LUT-Datei (Format, CRC...)     #
- * #    NO_IDENT_BLOCK     die LUT-Datei enthlt keinen IDENT Block     #
- * #    OK                 Erfolg                                       #
- * ######################################################################
- */
-DLL_EXPORT int set_ident(char *ident,char *lut_name);
-
-/*
- * ######################################################################
- * # Definition eines Datenblocks der LUT-Datei. Ein Block kann belie-  #
- * # bige Daten enthalten; Standard sind z.B. Prfziffermethoden oder   #
- * # Banknamen. Blocks, die ein HighByte >1 haben, knnen beliebig      #
- * # benutzerdefiniert werden; Blocks mit HighByte 0 und 1 sind fr     #
- * # interne Zwecke der Library reserviert.                             #
- * #                                                                    #
- * # Datenblocks mit ungeradem Typ sind komprimierte Daten; Datenblocks #
- * # mit geradem Typ sind unkomprimierte Daten. Zur Kompression wird    #
- * # die (freie) zlib benutzt (gleicher Algorithmus wie in ZIP).        #
- * ######################################################################
- */
-typedef struct{
-   int type;            /* Typ des Datenblocks */
-   int size;            /* Gre des unkomprimierten Blocks */
-   int compressed_size; /* Gre des komprimierten Blocks */
-   char *data;          /* Pointer auf den Datenbereich */
-} LUT_BLOCK;
-
-/* ######################################################################
- * # copy_lut(): einen oder mehrere Blocks einer LUT-Datei kopieren.    #
- * #                                                                    #
- * # Mit dieser Funktion knnen mehrere (oder alle) Blocks einer        #
- * # LUT-Datei in eine neue Datei kopiert werden. Fr die neue Datei    #
- * # kann die Anzahl der Verzeichniseintrge neu gesetzt werden (Die    #
- * # Funktion wird normaler- weise bentigt, falls das Verzeichnis      #
- * # einer LUT-Datei voll ist).                                         #
- * #                                                                    #
- * # Parameter:                                                         #
- * #    src:         Name der Eingabedatei                              #
- * #    dst:         Name der Zieldatei                                 #
- * #    types:       (int-) Array der zu kopierenden Blocks.            #
- * #                 Die Liste mu durch einen Eintrag mit 0            #
- * #                 abgeschlossen werden.                              #
- * #    dir_entries: Anzahl der Verzeichniseintrge der neuen Datei.    #
- * #                 Die Anzahl kann grer oder kleiner sein als die   #
- * #                 der alten Datei; sie mu nur gro genug sein, um   #
- * #                 alle kopierten Blocks aufzunehmen.                 #
- * #                                                                    #
- * # Rckgabewerte:                                                     #
- * #                                                                    #
- * ######################################################################
- */
-DLL_EXPORT   int copy_lut(char *src,char *dst,int *types[],int dir_entries);
-
-/* ######################################################################
- * # append_lut(): einen Block an eine LUT-Datei anhngen.              #
- * #                                                                    #
- * # Mit dieser Funktion wird ein Block an die LUT-Datei angehngt.     #
- * # Falls in der Datei schon ein Block dieses Typs existiert, wird er  #
- * # durch den neuen Block ersetzt; der Speicherplatz des alten Blocks  #
- * # wird jedoch nicht freigegeben (dies kann durch copy_lut()          #
- * # geschehen).                                                        #
- * #                                                                    #
- * # Parameter:                                                         #
- * #    lut_name: Name der Eingabedatei                                 #
- * #    block:    neu einzufgender Block. Falls der Blocktyp eine      #
- * #              ungerade Zahl ist, wird der Datenblock vor dem        #
- * #              Einfgen in die LUT-Datei komprimiert, bei einem      #
- * #              geraden Blocktyp wird er direkt eingefgt. Typ und    #
- * #              Gren (komprimiert bzw. unkomprimiert) des           #
- * #              Datenblocks werden ebenfalls in die LUT-Datei         #
- * #              geschrieben.                                          #
- * #                                                                    #
- * # Rckgabewerte:                                                     #
- * #                                                                    #
- * ######################################################################
- */
-DLL_EXPORT int append_lut(char *lut_name, LUT_BLOCK *block);
-
-/* ######################################################################
- * # get_block(): einen Block aus einer LUT-Datei extrahieren.          #
- * #                                                                    #
- * #                                                                    #
- * # Diese Funktion extrahiert einen Block aus der LUT-Datei. In der    #
- * # Struktur block sollte der Typ des zu extrahierenden Blocks         #
- * # angegeben werden; falls in der LUT-Datei ein Block dieses Typs     #
- * # gefunden wird (komprimiert oder unkomprimiert), wird er (bei       #
- * # Bedarf) dekomprimiert und in die Struktur geschrieben. Die         #
- * # Rckgabedaten sind immer unkomprimiert.                            #
- * #                                                                    #
- * # Parameter:                                                         #
- * #    lut_name: Name der LUT-Datei                                    #
- * #                                                                    #
- * #    block:    Pointer auf eine Block-Struktur. Beim Aufruf sollte   #
- * #              der Typ des zu extrahierenden Block gesetzt sein; die #
- * #              Funktion allokiert fr die Blockdaten den bentigten  #
- * #              Speicher und gibt in der Struktur einen Pointer auf   #
- * #              diese Daten zurck. Falls der Block in der LUT-Datei  #
- * #              komprimiert war, wird er vor der Rckgabe dekompri-   #
- * #              miert. Falls ein komprimierter Block angefordert      #
- * #              wurde, und in der Struktur ein unkomprimierter Block  #
- * #              desselben Typs gefunden wird, wird dieser zurck-     #
- * #              gegeben, bzw. genauso umgekehrt. Die zurckgegebenen  #
- * #              Daten sind jedoch immer unkomprimiert.                #
- * #                                                                    #
- * # Rckgabewerte:                                                     #
- * #                                                                    #
- * ######################################################################
- */
-DLL_EXPORT int get_block(char *lut_name, LUT_BLOCK *block);
-
 /*
  * ######################################################################
  * # get_kto_check_version(): Version und Releasedate der library holen #
